==> automation_rest_server-2.2.20.tar.gz: automation_rest_server-2.2.20/automation_rest_server/test_framework/engine/nose_engine.py <==
import os
from nose import run
from utils import log
import time
import subprocess


class NoseEngine(object):

    def __init__(self):
        self.working_path = os.environ["working_path"]
        self.log_path = self.get_log_path()

    def get_log_path(self):
        log_path = os.path.join(self.working_path, "log")
        if os.path.exists(log_path) is False:
            os.mkdir(log_path)
        return log_path

    @staticmethod
    def get_msg(out, err):
        msg = str()
        if err is not None:
            msg += err.decode('utf-8')
        if out is not None:
            msg += out.decode('utf-8')
        return msg

    def save_msg(self, msg, test_case):
        test_function = test_case.split(".")
        log_file = "{}_{}.log".format(test_function[-1],time.time())
        log_path = os.path.join(self.log_path, log_file)
        with open(log_path, "w") as file_:
            file_.write(msg)
        return log_path

    def command_run_test(self, test_case, test_path):
        test_function = test_case.split(".")
        xml_name = "nosetests_%s_%s.xml" % (test_function[-1], time.time())
        xml_path = os.path.join(self.log_path, xml_name)
        command_line = "nosetests --exe --nocapture --with-xunit --xunit-file={} -x {}"\
            .format(xml_path, test_path)
        child1 = subprocess.Popen(command_line, shell=True, stdout=subprocess.PIPE, stderr=subprocess.STDOUT)
        std_out, std_err = child1.communicate()
        msg = self.get_msg(std_out, std_err)
        log_path = self.save_msg(msg, test_case)
        ret = True if child1.returncode == 0 else False
        return ret, log_path

    def run(self, test_case, test_path, parameters, queue):
        ret, log_path = self.command_run_test(test_case, test_path)
        if ret is True:
            log.INFO("TestCase run succeed.%s", test_case)
        else:
            log.ERR("TestCase run failed. %s", test_case)
        result = {"name":test_case, "result": ret, "log_path": log_path}
        queue.put(result)
        return ret

==> automation_rest_server-2.5.2.tar.gz: automation_rest_server-2.5.2/automation_rest_server/test_framework/engine/nose_engine.py <==
import os
from nose import run
from utils import log
import time
import subprocess


class NoseEngine(object):

    def __init__(self):
        self.working_path = os.environ["working_path"]
        self.log_path = self.get_log_path()

    def get_log_path(self):
        log_path = os.path.join(self.working_path, "log")
        if os.path.exists(log_path) is False:
            os.mkdir(log_path)
        return log_path

    @staticmethod
    def get_msg(out, err):
        msg = str()
        if err is not None:
            msg += err.decode('utf-8')
        if out is not None:
            msg += out.decode('utf-8')
        return msg

    def save_msg(self, msg, test_case):
        test_function = test_case.split(".")
        log_file = "{}_{}.log".format(test_function[-1],time.time())
        log_path = os.path.join(self.log_path, log_file)
        with open(log_path, "w") as file_:
            file_.write(msg)
        return log_path

    def command_run_test(self, test_case, test_path):
        test_function = test_case.split(".")
        xml_name = "nosetests_%s_%s.xml" % (test_function[-1], time.time())
        xml_path = os.path.join(self.log_path, xml_name)
        command_line = "nosetests --exe --nocapture --with-printlog --with-xunit --xunit-file={} -x {}"\
            .format(xml_path, test_path)
        child1 = subprocess.Popen(command_line, shell=True)
        return_code = child1.wait()
        ret = True if return_code == 0 else False
        return ret, xml_path

    def run(self, test_case, test_path, parameters, queue):
        ret,  xml_path = self.command_run_test(test_case, test_path)
        if ret is True:
            log.INFO("TestCase run succeed.%s", test_case)
        else:
            log.ERR("TestCase run failed. %s", test_case)
        result = {"name":test_case, "result": ret, "log":xml_path, "xml_path": xml_path}
        queue.put(result)
        return ret
